@@ -441,7 +441,7 @@ def load_model(model_weights_path:str = "better2129Mar21.pt"):
 
 
 class Translit():
-    def __init__(self, model_weights_path:str):
+    def __init__(self, model_weights_path:str = "better2129Mar21.pt"):
         self.model, self.hi_char_vocab, self.hi_en_char_vocab, self.device = load_model(model_weights_path)
 
     def transliterate(self, word:str):
